import { MongoClient } from "mongodb";


if(!process.env.MONGODB_URI || !process.env.MONGODB_DB) {
    throw new Error("Please define MONGODB_URI and MONGODB_DB environment variables inside .env");
}

const uri = process.env.MONGODB_URI;
const dbName = process.env.MONGODB_DB;
const options = {};

const mongo = new MongoClient(uri, options);

export const connect = async () => {
    await mongo.connect();
    // return mongo.db(dbName);
}

export const disconnect = async () => {
    mongo.close();
}

export const getDB = async () => {
    await connect();
    return mongo.db(dbName);
}

export const Users = async () => {
    const db = await getDB();
    return db.collection('users');
}

export const AccessTokens = async () => {
    const db = await getDB();
    return db.collection('accessTokens');
}

export const Planets = async () => {
    const db = await getDB();
    return db.collection('planets');
}